Description
===========

This role provides base methods for each system role.

Requirement
===========

function defined variables
--------------------------

- function_packages (for container creation)

User defined variables
----------------------

- users
- usergroups
- network.hostname
- timezone

Variables
---------

* system_home_mirror:
  * description:
    * URL of the producer's package repository
  * hint: This variable is set by each system.

* system_local_mirror:
  * description:
    * URL of the local package repository

* system_mirror_directory:
  * description:
    * path to the root mirror directory on system for all system
  * hint: This variable is set by function role.

* system_supported_architures:
  * description:
    * list of system architectures supported by the system role; needed for installer und mirror
  * hint: This variable is set by each system.

* system_supported_releases:
  * description:
    * list of system releases supported by the system role; needed for installer und mirror
  * hint: This variable is set by each system.

* system_container_base_config:
  * description:
    * path to the base configuration file for containers
  * hint: default file is provided by this system role

* system_container_root: 
  * description:
    * path to the root directory for each jail 
  * hint: default file is provided by this system role

* system_suppress_container_creation:
  * description:
    * If this option is set to true, the system will be prepared for container usage, but none will be installed.
  * choises: [true, false]
  * default: false

* system_installer_path:
  * description:
    * destination path to the directory for the installer

* system_answer_path:
  * description:
    * destination path to the directory for the answer file

* system_name:
  * description:
    * contains the distribution name of a system; needed for gatherpackages

* system_gathered_packages:
  * description:
    * list of all packages; result of gatherpackages 

* system_upgrade_states:
  * description:
    * a dictionary with the results of upgrade (see features)

* system_app_root:
  * description:
    * contains the general path for applications without final path separator
    * must be set in defaults/main.yml of each system role 
  * examples:
    * Linux: system_app_root: "/usr"
    * FreeBSD: system_app_root: "/usr/local"
    * OpenBSD: system_app_root: "/usr/local"
    * NetBSD: system_app_root: "/usr/pkg"
  * default: undefined

* system_config_directory:
  * description:
    * contains the general path for configuration files of applications without final path separator
    * must be set in defaults/main.yml of each system role 
  * examples:
    * Linux: system_app_root: "/etc"
    * FreeBSD: system_app_root: "/usr/local/etc"
    * OpenBSD: system_app_root: "/etc"
    * NetBSD: system_app_root: "/usr/pkg/etc"
  * default: undefined
  
* system_fallback_admin_method
  * description
    * This option specifies the fallback method for the administrative access to a system.
    * Two values are currently possible: `root` and `sudo`
    * The value `root` enables and sets the password of the root user.
    * The value `sudo` disables the password of the root user and installs the sudo utility. It requires the SDM package `package.auth.sudo`.
    * The password for both methods will be stored in the \<ansible_passwords\>-directory.
  * default: root
  * choices: 
    * root
    * sudo
  * Hint: This option is currently under development. Please use it carefully. 
  
* system_fallback_sudo_username
  * description:
    * The option `system_fallback_sudo_username` specifies the username with administrative access permissions.
    * The username does not have to be defined in the global variable `users`.
    * It is only considered, if the value of `system_fallback_admin_method` is set to `sudo`.
    * The password for this user is stored in the \<ansible_passwords\>-directory.
  * default: ansible
  * Hint: This option is currently under development. Please use it carefully. 

* system_fallback_sudo_groupname
  * description:
    * This option specifies the groupname with administrative access permissions. 
    * The groupname does not have to be defined in the global variable `group`.
    * It is only considered, if the value of `system_fallback_admin_method` is set to `sudo`.
  * default: sudo
  * Hint: This option is currently under development. Please use it carefully. 

Processes
=========

main
----
1. execute system configuration (see configure)

configure
---------

1. set hostname 
2. remove obsolete groups
2. remove obsolete users
2. add groups
3. add users  
4. append groups to users, if defined
5. set timezone

Features
========

The task upgrade have to generate a dictionary with the states of upgrade process. The dictionary has following structure:

<inventory\_hostname>:
    host: True|False
    <name of container 1>: True|False
    ...
    <name container n>: True|False

The key `host` contains the upgrade state of the inventory host. 
The state `True` means that the host or container was upgraded. `False` that there are no upgrades for them. 

